@@ -15,9 +15,12 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id: ephy-history.h 7244 2007-08-06 09:16:45Z diegoe $
  */
 
+#if !defined (__EPHY_EPIPHANY_H_INSIDE__) && !defined (EPIPHANY_COMPILATION)
+#error "Only <epiphany/epiphany.h> can be included directly."
+#endif
+
 #ifndef EPHY_HISTORY_H
 #define EPHY_HISTORY_H
 
@@ -63,60 +66,63 @@ struct _EphyHistory
 
 struct _EphyHistoryClass
 {
-        GObjectClass parent_class;
+	GObjectClass parent_class;
 
 	/* Signals */
-	gboolean (* add_page)	(EphyHistory *history,
-				 const char *url,
-				 gboolean redirect,
-				 gboolean toplevel);
-	void	(* visited)	(EphyHistory *history,
-				 const char *url);
-	void	(* cleared)	(EphyHistory *history);
-
-	void	(* redirect)	(EphyHistory *history,
-				 const char *from_uri,
-				 const char *to_uri);
+	gboolean (* add_page)	 (EphyHistory *history,
+				  const char *url,
+				  gboolean redirect,
+				  gboolean toplevel);
+	void	(* visited)	 (EphyHistory *history,
+				  const char *url);
+	void	(* cleared)	 (EphyHistory *history);
+				 
+	void	(* redirect)	 (EphyHistory *history,
+				  const char *from_uri,
+				  const char *to_uri);
+	void	(* icon_updated) (EphyHistory *history,
+				  const char *address,
+				  const char *icon);
 };
 
 GType		ephy_history_get_type		(void);
 
 EphyHistory    *ephy_history_new		(void);
 
-EphyNode       *ephy_history_get_hosts          (EphyHistory *gh);
+EphyNode       *ephy_history_get_hosts		(EphyHistory *gh);
 
 EphyNode       *ephy_history_get_host		(EphyHistory *gh,
 						 const char *url);
 
-EphyNode       *ephy_history_get_pages          (EphyHistory *gh);
+EphyNode       *ephy_history_get_pages		(EphyHistory *gh);
 
-EphyNode       *ephy_history_get_page           (EphyHistory *gh,
+EphyNode       *ephy_history_get_page		(EphyHistory *gh,
 						 const char *url);
 
-void            ephy_history_add_page           (EphyHistory *gh,
+void		ephy_history_add_page		(EphyHistory *gh,
 						 const char *url,
 						 gboolean redirect,
 						 gboolean toplevel);
 
-gboolean        ephy_history_is_page_visited    (EphyHistory *gh,
+gboolean	ephy_history_is_page_visited	(EphyHistory *gh,
 						 const char *url);
 
-int             ephy_history_get_page_visits    (EphyHistory *gh,
+int		ephy_history_get_page_visits	(EphyHistory *gh,
 						 const char *url);
 
-void            ephy_history_set_page_title     (EphyHistory *gh,
+void		ephy_history_set_page_title	(EphyHistory *gh,
 						 const char *url,
 						 const char *title);
 
 const char     *ephy_history_get_last_page	(EphyHistory *gh);
 
-void		ephy_history_set_icon           (EphyHistory *gh,
+void		ephy_history_set_icon		(EphyHistory *gh,
 						 const char *url,
 						 const char *icon);
 const char     *ephy_history_get_icon		(EphyHistory *gh,
 						 const char *url);
 
-void            ephy_history_clear              (EphyHistory *gh);
+void		ephy_history_clear		(EphyHistory *gh);
 
 gboolean	ephy_history_is_enabled		(EphyHistory *history);
 
