@@ -16,7 +16,6 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id$
  */
 
 #include "config.h"
@@ -29,15 +28,14 @@
 
 #include <stdlib.h>
 #include <string.h>
-#include <gtk/gtktogglebutton.h>
-#include <gtk/gtkradiobutton.h>
-#include <gtk/gtkcombobox.h>
-#include <gtk/gtkspinbutton.h>
-#include <gtk/gtkeditable.h>
-#include <gtk/gtkentry.h>
-#include <gtk/gtksizegroup.h>
-#include <gtk/gtkdialog.h>
-#include <glade/glade-xml.h>
+#include <gtk/gtk.h>
+
+/**
+ * SECTION:ephy-dialog
+ * @short_description: A customized #GtkDialog for Epiphany
+ *
+ * A customized #GtkDialog for Epiphany.
+ */
 
 enum
 {
@@ -155,15 +153,18 @@ set_sensitivity (PropertyInfo *info, gboolean sensitive)
 
 		for (l = list; l != NULL; l = l->next)
 		{
+			sensitive = gtk_widget_is_sensitive (GTK_WIDGET (l->data)) && sensitive;
 			gtk_widget_set_sensitive (GTK_WIDGET (l->data), sensitive);
 		}
 	}
 	else if (info->widget_type == PT_EDITABLE)
 	{
+		sensitive = gtk_widget_is_sensitive (info->widget) && sensitive;
 		gtk_editable_set_editable (GTK_EDITABLE (info->widget), sensitive);
 	}
 	else
 	{
+		sensitive = gtk_widget_is_sensitive (info->widget) && sensitive;
 		gtk_widget_set_sensitive (info->widget, sensitive);
 	}
 }
@@ -927,7 +928,7 @@ disconnect_signals (gpointer key, PropertyInfo *info, EphyDialog *dialog)
 }
 
 static void
-init_props (EphyDialog *dialog, const EphyDialogProperty *properties, GladeXML *gxml)
+init_props (EphyDialog *dialog, const EphyDialogProperty *properties, GtkBuilder *builder)
 {
 	int i;
 
@@ -942,7 +943,7 @@ init_props (EphyDialog *dialog, const EphyDialogProperty *properties, GladeXML *
 		info->string_enum = NULL;
 		info->data_col = -1;
 
-		info->widget = glade_xml_get_widget (gxml, info->id);
+		info->widget = (GtkWidget*)gtk_builder_get_object (builder, info->id);
 		
 		if (GTK_IS_COMBO_BOX (info->widget))
 		{
@@ -1075,12 +1076,20 @@ impl_construct (EphyDialog *dialog,
 		const char *domain)
 {
 	EphyDialogPrivate *priv = dialog->priv;
-	GladeXML *gxml;
+	GtkBuilder *builder;
+	GError *error = NULL;
 
-	gxml = glade_xml_new (file, name, domain);
-	g_return_if_fail (gxml != NULL);
+	builder = gtk_builder_new ();
+	gtk_builder_set_translation_domain (builder, domain);
+	gtk_builder_add_from_file (builder, file, &error);
+	if (error)
+	{
+		g_warning ("Unable to load UI file %s: %s", file, error->message);
+		g_error_free (error);
+		return;
+	}
 
-	priv->dialog = glade_xml_get_widget (gxml, name);
+	priv->dialog = (GtkWidget*)gtk_builder_get_object (builder, name);
 	g_return_if_fail (priv->dialog != NULL);
 
 	if (priv->name == NULL)
@@ -1090,13 +1099,13 @@ impl_construct (EphyDialog *dialog,
 
 	if (properties)
 	{
-		init_props (dialog, properties, gxml);
+		init_props (dialog, properties, builder);
 	}
 
 	g_signal_connect_object (dialog->priv->dialog, "destroy",
 				 G_CALLBACK(dialog_destroy_cb), dialog, 0);
 
-	g_object_unref (gxml);
+	g_object_unref (builder);
 }
 
 static void
@@ -1124,18 +1133,38 @@ impl_show (EphyDialog *dialog)
 	gtk_window_present (GTK_WINDOW (dialog->priv->dialog));
 }
 
+/**
+ * ephy_dialog_set_modal:
+ * @dialog: an #EphyDialog
+ * @is_modal: %TRUE to make @dialog modal
+ *
+ * Sets @dialog to be modal or not.
+ **/
 void
 ephy_dialog_set_modal (EphyDialog *dialog,
 		       gboolean is_modal)
 {
+	g_return_if_fail (EPHY_IS_DIALOG (dialog));
+
 	dialog->priv->modal = is_modal != FALSE;
 
 	gtk_window_set_modal (GTK_WINDOW(dialog->priv->dialog), is_modal);
 }
 
+/**
+ * ephy_dialog_add_enum:
+ * @dialog: an #EphyDialog
+ * @property_id: string identifier of the property to modify
+ * @n_items: length of @items array
+ * @items: array of items to add to @property_id
+ *
+ * Modifies the property identified by @property_id in @dialog to have its
+ * string_enum member set to a #GList constructed with the elements given as
+ * @items.
+ **/
 void
 ephy_dialog_add_enum (EphyDialog *dialog,
-		      const char *id,
+		      const char *property_id,
 		      guint n_items,
 		      const char *const *items)
 {
@@ -1143,7 +1172,9 @@ ephy_dialog_add_enum (EphyDialog *dialog,
 	int i = 0;
 	GList *l = NULL;
 
-	info = lookup_info (dialog, id);
+	g_return_if_fail (EPHY_IS_DIALOG (dialog));
+
+	info = lookup_info (dialog, property_id);
 	g_return_if_fail (info != NULL);
 
 	for (i = 0; i < n_items; i++)
@@ -1154,19 +1185,39 @@ ephy_dialog_add_enum (EphyDialog *dialog,
 	info->string_enum = g_list_reverse (l);
 }
 
+/**
+ * ephy_dialog_set_data_column:
+ * @dialog: an #EphyDialog
+ * @property_id: string identifier of the property to modify
+ * @column: value for the data_col member of @property_id
+ *
+ * Sets the data_col member of the property identified by @property_id in @dialog
+ * to @column.
+ **/
 void
 ephy_dialog_set_data_column (EphyDialog *dialog,
-			     const char *id,
+			     const char *property_id,
 			     int column)
 {
 	PropertyInfo *info;
 
-	info = lookup_info (dialog, id);
+	g_return_if_fail (EPHY_IS_DIALOG (dialog));
+
+	info = lookup_info (dialog, property_id);
 	g_return_if_fail (info != NULL);
 
 	info->data_col = column;
 }
 
+/**
+ * ephy_dialog_set_pref:
+ * @dialog: an #EphyDialog
+ * @property_id: string identifier of the property to modify
+ * @pref: preference value of the property identified by @property_id
+ *
+ * Sets the pref member of the property of @dialog identified by @property_id
+ * to @pref.
+ **/
 void
 ephy_dialog_set_pref (EphyDialog *dialog,
 		      const char *property_id,
@@ -1174,6 +1225,8 @@ ephy_dialog_set_pref (EphyDialog *dialog,
 {
 	PropertyInfo *info;
 
+	g_return_if_fail (EPHY_IS_DIALOG (dialog));
+
 	info = lookup_info (dialog, property_id);
 	g_return_if_fail (info != NULL);
 
@@ -1192,6 +1245,15 @@ ephy_dialog_set_pref (EphyDialog *dialog,
 	}
 }
 
+/**
+ * ephy_dialog_set_size_group:
+ * @dialog: an #EphyDialog
+ * @first_id: id of a widget in @dialog
+ * @Varargs: a %NULL-terminated list of widget ids
+ *
+ * Put @first_id and @Varargs widgets into the same #GtkSizeGroup.
+ * Note that this are all widgets inside @dialog.
+ **/
 void
 ephy_dialog_set_size_group (EphyDialog *dialog,
 			    const char *first_id,
@@ -1200,6 +1262,8 @@ ephy_dialog_set_size_group (EphyDialog *dialog,
 	GtkSizeGroup *size_group;
 	va_list vl;
 
+	g_return_if_fail (EPHY_IS_DIALOG (dialog));
+
 	size_group = gtk_size_group_new (GTK_SIZE_GROUP_HORIZONTAL);
 
 	va_start (vl, first_id);
@@ -1223,6 +1287,18 @@ ephy_dialog_set_size_group (EphyDialog *dialog,
 	g_object_unref (size_group);
 }
 
+/**
+ * ephy_dialog_construct:
+ * @dialog: an #EphyDialog
+ * @properties: an array of #EphyDialogProperty elements
+ * @file: the path to a #GtkBuilder file
+ * @name: name of the widget to use for @dialog, found in @file
+ * @domain: translation domain to set for @dialog
+ *
+ * Constructs the widget part of @dialog using the widget identified by @name
+ * in the #GtkBuilder file found at @file. Fills the dialog properties with
+ * @properties and sets translation domain to @domain.
+ **/
 void
 ephy_dialog_construct (EphyDialog *dialog,
 		       const EphyDialogProperty *properties,
@@ -1234,13 +1310,29 @@ ephy_dialog_construct (EphyDialog *dialog,
 	klass->construct (dialog, properties, file, name, domain);
 }
 
+/**
+ * ephy_dialog_show:
+ * @dialog: an #EphyDialog
+ *
+ * Shows @dialog on screen.
+ **/
 void
 ephy_dialog_show (EphyDialog *dialog)
 {
-	EphyDialogClass *klass = EPHY_DIALOG_GET_CLASS (dialog);
+	EphyDialogClass *klass;
+
+	g_return_if_fail (EPHY_IS_DIALOG (dialog));
+
+	klass = EPHY_DIALOG_GET_CLASS (dialog);
 	klass->show (dialog);
 }
 
+/**
+ * ephy_dialog_hide:
+ * @dialog: an #EphyDialog
+ *
+ * Calls gtk_widget_hide on @dialog.
+ **/
 void
 ephy_dialog_hide (EphyDialog *dialog)
 {
@@ -1250,9 +1342,19 @@ ephy_dialog_hide (EphyDialog *dialog)
 	gtk_widget_hide (dialog->priv->dialog);
 }
 
+/**
+ * ephy_dialog_run:
+ * @dialog: an #EphyDialog
+ *
+ * Runs gtk_dialog_run on @dialog and waits for a response.
+ *
+ * Returns: the user response to gtk_dialog_run or 0 if @dialog is not valid
+ **/
 int
 ephy_dialog_run (EphyDialog *dialog)
 {
+	g_return_val_if_fail (EPHY_IS_DIALOG (dialog), 0);
+
 	ephy_dialog_show (dialog);
 
 	gtk_window_group_add_window (ephy_gui_ensure_window_group (GTK_WINDOW (dialog->priv->parent)),
@@ -1261,43 +1363,76 @@ ephy_dialog_run (EphyDialog *dialog)
 	return gtk_dialog_run (GTK_DIALOG (dialog->priv->dialog));
 }
 
+/**
+ * ephy_dialog_get_control:
+ * @dialog: an #EphyDialog
+ * @property_id: the string identifier of the requested control
+ *
+ * Gets the internal widget corresponding to @property_id from @dialog.
+ * Return value: (transfer none): the #GtkWidget corresponding to @property_id
+ * or %NULL
+ **/
 GtkWidget *
 ephy_dialog_get_control (EphyDialog *dialog,
 			 const char *property_id)
 {
 	PropertyInfo *info;
 
+	g_return_val_if_fail (EPHY_IS_DIALOG (dialog), NULL);
+
 	info = lookup_info (dialog, property_id);
 	g_return_val_if_fail (info != NULL, NULL);
 
 	return info->widget;
 }
 
+/**
+ * ephy_dialog_get_controls:
+ * @dialog: an #EphyDialog
+ * @first_id: identifier of the requested control
+ * @Varargs: a %NULL terminated list of extra pairs of properties as const char
+ * and store locations as #GtkWidgets.
+ *
+ * Gets the requested controls according to given property-store_location pairs.
+ * Properties are given as strings (const char *), controls are returned as
+ * #GtkWidget elements.
+ * Rename to: ephy_dialog_get_controls
+ **/
 void
 ephy_dialog_get_controls (EphyDialog *dialog,
-			  const char *property_id,
+			  const char *first_id,
 			  ...)
 {
 	PropertyInfo *info;
 	GtkWidget **wptr;
 	va_list varargs;
 
-	va_start (varargs, property_id);
+	va_start (varargs, first_id);
 
-	while (property_id != NULL)
+	while (first_id != NULL)
 	{
-		info = lookup_info (dialog, property_id);
+		info = lookup_info (dialog, first_id);
 		g_return_if_fail (info != NULL);
 
 		wptr = va_arg (varargs, GtkWidget **);
 		*wptr = info->widget;
 
-		property_id = va_arg (varargs, const char *);
+		first_id = va_arg (varargs, const char *);
 	}
 
 	va_end (varargs);
 }
 
+/**
+ * ephy_dialog_get_value:
+ * @dialog: an #EphyDialog
+ * @property_id: property name
+ * @value: (out): location to store the value of @property_id
+ *
+ * Gets the value of @property_id and stores it in @value.
+ *
+ * Returns: %TRUE if the operation was successful
+ */
 gboolean
 ephy_dialog_get_value (EphyDialog *dialog,
 		       const char *property_id,
@@ -1305,12 +1440,22 @@ ephy_dialog_get_value (EphyDialog *dialog,
 {
 	PropertyInfo *info;
 
+	g_return_val_if_fail (EPHY_IS_DIALOG (dialog), FALSE);
+
 	info = lookup_info (dialog, property_id);
 	g_return_val_if_fail (info != NULL, FALSE);
 
 	return set_value_from_info (info, value);
 }
 
+/**
+ * ephy_dialog_set_value:
+ * @dialog: an #EphyDialog
+ * @property_id: @dialog property to set
+ * @value: value to set @property_id to
+ *
+ * Sets the property identified by @property_id to @value in @dialog.
+ **/
 void
 ephy_dialog_set_value (EphyDialog *dialog,
 		       const char *property_id,
@@ -1318,6 +1463,8 @@ ephy_dialog_set_value (EphyDialog *dialog,
 {
 	PropertyInfo *info;
 
+	g_return_if_fail (EPHY_IS_DIALOG (dialog));
+
 	info = lookup_info (dialog, property_id);
 	g_return_if_fail (info != NULL);
 
@@ -1377,6 +1524,14 @@ ephy_dialog_finalize (GObject *object)
 	G_OBJECT_CLASS (parent_class)->finalize (object);
 }
 
+/**
+ * ephy_dialog_get_parent:
+ * @dialog: an #EphyDialog
+ *
+ * Gets @dialog's parent-window.
+ *
+ * Returns: (transfer none): the parent-window of @dialog
+ **/
 GtkWidget *
 ephy_dialog_get_parent (EphyDialog *dialog)
 {
@@ -1385,10 +1540,19 @@ ephy_dialog_get_parent (EphyDialog *dialog)
 	return dialog->priv->parent;
 }
 
+/**
+ * ephy_dialog_set_parent:
+ * @dialog: an #EphyDialog
+ * @parent: new parent for @dialog
+ *
+ * Sets @parent as the parent-window of @dialog.
+ **/
 void
 ephy_dialog_set_parent (EphyDialog *dialog,
 			GtkWidget *parent)
 {
+	g_return_if_fail (EPHY_IS_DIALOG (dialog));
+
 	dialog->priv->parent = parent;
 
 	g_object_notify (G_OBJECT (dialog), "parent-window");
@@ -1465,6 +1629,14 @@ ephy_dialog_class_init (EphyDialogClass *klass)
 	klass->construct = impl_construct;
 	klass->show = impl_show;
 
+	/**
+	* EphyDialog::changed:
+	* @dialog: the object on which the signal is emitted
+	* @value: new value of the modified widget, as a #GValue
+	*
+	* Emitted everytime a child widget of the dialog has its changed or
+	* clicked signal emitted.
+	*/
 	signals[CHANGED] =
 		g_signal_new ("changed",
 			      EPHY_TYPE_DIALOG,
@@ -1476,6 +1648,11 @@ ephy_dialog_class_init (EphyDialogClass *klass)
 			      1,
 			      G_TYPE_POINTER);
 
+	/**
+	* EphyDialog:parent-window:
+	*
+	* Dialog's parent window.
+	*/
 	g_object_class_install_property (object_class,
 					 PROP_PARENT_WINDOW,
 					 g_param_spec_object ("parent-window",
@@ -1484,14 +1661,24 @@ ephy_dialog_class_init (EphyDialogClass *klass)
 							      GTK_TYPE_WINDOW,
 							      G_PARAM_READWRITE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB));
 
+	/**
+	* EphyDialog:modal:
+	*
+	* Whether the dialog is or not modal.
+	*/
 	g_object_class_install_property (object_class,
 					 PROP_MODAL,
-					 g_param_spec_boolean ("Modal",
+					 g_param_spec_boolean ("modal",
 							       "Modal",
 							       "Modal dialog",
 							       FALSE,
 							       G_PARAM_READWRITE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB));
 
+	/**
+	* EphyDialog:persist-position:
+	*
+	* If dialog position should be persistent.
+	*/
 	g_object_class_install_property (object_class,
 					 PROP_PERSIST_POSITION,
 					 g_param_spec_boolean ("persist-position",
@@ -1501,6 +1688,11 @@ ephy_dialog_class_init (EphyDialogClass *klass)
 							       G_PARAM_READWRITE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB |
 							       G_PARAM_CONSTRUCT_ONLY));
 
+	/**
+	* EphyDialog:default-width:
+	*
+	* The dialog default width.
+	*/
 	g_object_class_install_property (object_class,
 					 PROP_DEFAULT_WIDTH,
 					 g_param_spec_int ("default-width",
@@ -1512,6 +1704,11 @@ ephy_dialog_class_init (EphyDialogClass *klass)
 							   G_PARAM_READWRITE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB |
 							   G_PARAM_CONSTRUCT_ONLY));
 
+	/**
+	* EphyDialog:default-height:
+	*
+	* The dialog default height.
+	*/
 	g_object_class_install_property (object_class,
 					 PROP_DEFAULT_HEIGHT,
 					 g_param_spec_int ("default-height",
@@ -1526,12 +1723,27 @@ ephy_dialog_class_init (EphyDialogClass *klass)
 	g_type_class_add_private (object_class, sizeof (EphyDialogPrivate));
 }
 
+/**
+ * ephy_dialog_new:
+ *
+ * Creates a new #EphyDialog.
+ *
+ * Returns: a new #EphyDialog
+ **/
 EphyDialog *
 ephy_dialog_new (void)
 {
 	return EPHY_DIALOG (g_object_new (EPHY_TYPE_DIALOG, NULL));
 }
 
+/**
+ * ephy_dialog_new_with_parent:
+ * @parent_window: a window to be parent of the new dialog
+ *
+ * Creates a new #EphyDialog with @parent_window as its parent.
+ *
+ * Returns: a new #EphyDialog
+ **/
 EphyDialog *
 ephy_dialog_new_with_parent (GtkWidget *parent_window)
 {
